---
name: Bug report
about: scVelo doesn’t do what it should? Please help us fix it!
title: ''
labels: bug
assignees: ''
---

<!-- Description of the bug: -->
...

<!-- Reproducible example in the code block below (if applicable, else delete): -->
```python
...
```

<!-- Error output in the code block below (if applicable, else delete): -->
<details>
<summary> Error </summary>
```pytb
...
```
</details>

#### Versions:
<!-- Output of scv.logging.print_versions() -->
> 
